==> cbol-1.5.tgz: cbol-1.5/parsing.php <==
<?php
	$graph=$_REQUEST["graph"];
	if (!isset($_REQUEST["graph"])) $graph=1;//]wϧμҦ
	if (strlen(trim($_REQUEST["engs"]))==0) 
	{
		echogb("SJgơI");
		die('');
	}
	$engs=$_REQUEST["engs"];
	if (strlen(trim($_REQUEST["chap"]))==0) 
	{
		echogb("SJơI");
		die('');
	}
	$chap=$_REQUEST["chap"];
	$sec=$_REQUEST["sec"];
/****** oӵ{ΨӯuJƶiJƮw ********/
require("config.php");
require("dbconfig.php");
require("code.php");
if ($graph) require("font.php");
require("lang.php");
echo "<head>\n";
 if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 echogb("<title>CBOL ¬ Parsing </title>\n");
 echo "</head>\n";
 echo "<center><body>\n";
 echogb("<h1>CBOL ¬ Parsing t</h1>");

$db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 /******sJ BHS tg ********/
 if ($sec==0)
     $QUERY="select A.id, A.engs, A.chap, A.sec, A.wid, A.word, A.sn, A.pro, A.wform, A.orig, A.exp, A.remark, A.username, A.modtime, main.chineses,main.chinesef from lparsing as A ,main where A.engs='$engs' and A.chap=$chap and A.engs=main.engs order by A.sec,A.wid";
 else 
     $QUERY="select A.id, A.engs, A.chap, A.sec, A.wid, A.word, A.sn, A.pro, A.wform, A.orig, A.exp, A.remark, A.username, A.modtime, main.chineses,main.chinesef from lparsing as A ,main where A.engs='$engs' and A.chap=$chap and A.sec=$sec and A.engs=main.engs order by A.wid";

 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echogb("Ʈw d ~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result);
 if ($numrow==0)
   {
        echogb("dơAЭקd߱AdI");
        exit;
   }
 $oldid=-1;
  $numrow=$numrow-1;
for ($i=0;$i<=$numrow;$i=$i+1)
{
   $ARAW=db_fetch_row($result,$i); //Ū@O
  if ($oldid!=(int) $ARAW[0]) //`F
  {
	if ($oldid>0)
	{
		$MSG=$MSG."</table>";
	   	$OUTMAIN=join( "", file( "parsing.cfg" ) );
	   	$OUTMAIN=str_replace("%engs%",$engs,$OUTMAIN);
		$OUTMAIN=str_replace("%chineses%",$ARAW[14],$OUTMAIN);
		$OUTMAIN=str_replace("%chinesef%",$ARAW[15],$OUTMAIN);
		$OUTMAIN=str_replace("%chap%",(int) $chap,$OUTMAIN);
		$OUTMAIN=str_replace("%sec%",$oldsec,$OUTMAIN);
		$OUTMAIN=str_replace("%book%",$book,$OUTMAIN);
		$OUTMAIN=str_replace("%origtxt%",$origtxt,$OUTMAIN);
		$big=str_replace("\n","\n\n",$big);
		$OUTMAIN=str_replace("%big%",$big,$OUTMAIN);
		$OUTMAIN=str_replace("%data%",$MSG,$OUTMAIN);
		/****** Nparsing %data% ******/
		echogb($OUTMAIN);
	}
 	if ($graph)
 		$origtxt=pfont(mscode($ARAW[5]));
 	else
 		$origtxt="<font face=\"COBSHebrew\" size=6>".htmlspecialchars(mscode($ARAW[5]))."</font>";
 	$big=$ARAW[10];
	$MSG="<table border=1>";
   	$MSG=$MSG."<tr><td align=\"center\">r</td><td align=\"center\">SN</td><td align=\"center\">rJR</td><td align=\"center\">쫬</td><td align=\"center\">²nNq</td><td align=\"center\">Ƶ</td></tr>";
	$oldid=(int) $ARAW[0];
	$oldsec=(int)$ARAW[3];
	continue; //Ĥ@ID@wOy½Ķ
  }
/******Bzrഫ ******/
   if ($graph)
   {
     $spec=pfont(mscode($ARAW[5]));
     $MSG=$MSG."<tr><td align=\"right\">$spec</td>\n";
   }
   else
   {
     $spec=htmlspecialchars(mscode($ARAW[5]));
     $MSG=$MSG."<tr><td align=\"right\"><font face=\"COBSHebrew\" size=6><nobr>$spec</nobr></font></td>\n";
   }
    //need to change
   $MSG=$MSG."<td><a href=\"s.php?N=1&k=$ARAW[6]\">$ARAW[6]</a></td>"; //SN
    /*******
   $ARAW[7]=hebpar($ARAW[7],$graph);//>
   $MSG=$MSG."<td>$ARAW[7]</td>";
    *****/
   $ARAW[8]=hebpar($ARAW[8],$graph);
   $MSG=$MSG."<td>$ARAW[8]</td>";//A
   if ($graph)
   {
      $spec=pfont(mscode($ARAW[9]));//쫬
      $MSG=$MSG."<td align=\"right\">$spec</td>";
   }
   else
   {
      $spec=htmlspecialchars(mscode($ARAW[9]));//쫬
      $MSG=$MSG."<td align=\"right\"><font face=\"COBSHebrew\" size=6><nobr>$spec</nobr></font></td>";
   }
   $ARAW[10]=hebpar($ARAW[10],$graph);
   $MSG=$MSG."<td>$ARAW[10]</td>";//²nNq
   $ARAW[11]=hebpar($ARAW[11],$graph);
   $MSG=$MSG."<td>$ARAW[11]</td></tr>";//Ƶ
}
$MSG=$MSG."</table>";
   $QUERY="select engs, chap, sec from lparsing  where id=$oldid + 1";
    $result1=db_exec($db_conn,$QUERY);
 if (!$result1){
                        echogb("Ʈwupdate~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result1);
 if ($numrow>0)
 {
        $ARA=db_fetch_row($result1,0); //Ū@O
        $ARA[0]=trim($ARA[0]);
        $NEXT=urlencode($ARA[0]);
	if ($sec>0)
        	$MSG=$MSG."<br>\n<a href=\"$PHP_SELF?graph={$graph}&engs={$NEXT}&chap={$ARA[1]}&sec={$ARA[2]}\">U@`</a>";
 	else
        	$MSG=$MSG."<br>\n<a href=\"$PHP_SELF?graph={$graph}&engs={$NEXT}&chap={$ARA[1]}\">U@</a>";
 }

/*******ݭnsX@U? urlencode($userinput) ******/
$OUTMAIN=join( "", file( "parsing.cfg" ) );
$OUTMAIN=str_replace("%engs%",$engs,$OUTMAIN);
$OUTMAIN=str_replace("%chineses%",$ARAW[14],$OUTMAIN);
$OUTMAIN=str_replace("%chinesef%",$ARAW[15],$OUTMAIN);
$OUTMAIN=str_replace("%chap%",(int) $chap,$OUTMAIN);
$OUTMAIN=str_replace("%sec%",$oldsec,$OUTMAIN);
$OUTMAIN=str_replace("%book%",$book,$OUTMAIN);
$OUTMAIN=str_replace("%origtxt%",$origtxt,$OUTMAIN);
$big=str_replace("\n","\n\n",$big);
$OUTMAIN=str_replace("%big%",$big,$OUTMAIN);
$OUTMAIN=str_replace("%data%",$MSG,$OUTMAIN);
/****** Nparsing %data% ******/
echogb($OUTMAIN);
echo "</center>";
echogb("pGo{~Ap<a href=\"mailto:bible@fhl.net\">CBOLpe</a>C\n");
echogb("ƥѱfkhѡA޳N<a href=\"http://www.fhl.net\">HRT</a>");
echogb("<a href=\"http://bible.fhl.net\">CBOLpe</a>ѡAgϥΦCǧۥC<br>");
echogb("CBOLpeƪvŧiĥ<a href=\"http://bible.fhl.net/new/fdl.txt\">GNU Free Documentation License</a>AUBS4/NA27PBHS");
echogb("tgvҦ̶ȱvHRT ߡC");
?>

==> cbol-1.7.tgz: cbol-1.7/parsing.php <==
<?php
	$graph=(int) $_REQUEST["graph"];
	if (!isset($_REQUEST["graph"])) $graph=1;//]wϧμҦ
	if (strlen(trim($_REQUEST["engs"]))==0) 
	{
		echogb("SJgơI");
		die('');
	}
	$engs=$_REQUEST["engs"];
	if (ereg("[[:punct:]]+",$engs)) die("ENGS $engs error!");//for hacker
	if (strlen(trim($_REQUEST["chap"]))==0) 
	{
		echogb("SJơI");
		die('');
	}
	$chap=(int) $_REQUEST["chap"];
	$sec=(int) $_REQUEST["sec"];
	$sec1=(int) $_REQUEST["sec1"];
	if ($sec1==0) $sec1=$sec;//oO`ξ㳹p
	if( $sec1<$sec)//Tw $sec <= $sec1
	{
		$stmpp=$sec1;
		$sec1=$sec;
		$sec=$stmpp;
	}
/****** oӵ{ΨӯuJƶiJƮw ********/
require("config.php");
require("dbconfig.php");
require("code.php");
if ($graph) require("font.php");
require("lang.php");
echo "<head>\n";
 if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 echogb("<title>CBOL ¬ Parsing </title>\n");
 echo "</head>\n";
 echo "<center><body>\n";
 echogb("<h1>CBOL ¬ Parsing t</h1>");

$db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 /******sJ BHS tg ********/
 if ($sec==0)
     $QUERY="select A.id, A.engs, A.chap, A.sec, A.wid, A.word, A.sn, A.pro, A.wform, A.orig, A.exp, A.remark, A.username, A.modtime, main.chineses,main.chinesef from lparsing as A ,main where A.engs='$engs' and A.chap=$chap and A.engs=main.engs order by A.sec,A.wid";
 else 
     $QUERY="select A.id, A.engs, A.chap, A.sec, A.wid, A.word, A.sn, A.pro, A.wform, A.orig, A.exp, A.remark, A.username, A.modtime, main.chineses,main.chinesef from lparsing as A ,main where A.engs='$engs' and A.chap=$chap and A.sec>=$sec and A.sec<=$sec1 and A.engs=main.engs order by A.sec,A.wid";

 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echogb("Ʈw d ~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result);
 if ($numrow==0)
   {
        echogb("dơAЭקd߱AdI");
        exit;
   }
 $oldid=-1;
 $oldsec=-1;
  $numrow=$numrow-1;
for ($i=0;$i<=$numrow;$i=$i+1)
{
   $ARAW=db_fetch_row($result,$i); //Ū@O
  if ($oldsec!=(int) $ARAW[3]) //`F
  {
	if ($oldid>0)
	{
		$MSG=$MSG."</table>";
	   	$OUTMAIN=join( "", file( "parsing.cfg" ) );
	   	$OUTMAIN=str_replace("%engs%",$engs,$OUTMAIN);
		$OUTMAIN=str_replace("%chineses%",$ARAW[14],$OUTMAIN);
		$OUTMAIN=str_replace("%chinesef%",$ARAW[15],$OUTMAIN);
		$OUTMAIN=str_replace("%chap%",(int) $chap,$OUTMAIN);
		$OUTMAIN=str_replace("%sec%",$oldsec,$OUTMAIN);
		$OUTMAIN=str_replace("%book%",$book,$OUTMAIN);
		$OUTMAIN=str_replace("%origtxt%",$origtxt,$OUTMAIN);
		$big=str_replace("\n","\n\n",$big);
		$OUTMAIN=str_replace("%big%",$big,$OUTMAIN);
		$OUTMAIN=str_replace("%data%",$MSG,$OUTMAIN);
		/****** Nparsing %data% ******/
		echogb($OUTMAIN);
	}
 	if ($graph)
 		$origtxt=pfont(mscode($ARAW[5]));
 	else
 		$origtxt="<font face=\"COBSHebrew\" size=6>".htmlspecialchars(mscode($ARAW[5]))."</font>";
 	$big=$ARAW[10];
	$MSG="<table border=1>";
   	$MSG=$MSG."<tr><td align=\"center\">r</td><td align=\"center\">SN</td><td align=\"center\">rJR</td><td align=\"center\">쫬</td><td align=\"center\">²nNq</td><td align=\"center\">Ƶ</td></tr>";
	$oldid=(int) $ARAW[0];
	$oldsec=(int)$ARAW[3];
	continue; //Ĥ@ID@wOy½Ķ
  }
/******Bzrഫ ******/
   if ($graph)
   {
     $spec=pfont(mscode($ARAW[5]));
     $MSG=$MSG."<tr><td align=\"right\">$spec</td>\n";
   }
   else
   {
     $spec=htmlspecialchars(mscode($ARAW[5]));
     $MSG=$MSG."<tr><td align=\"right\"><font face=\"COBSHebrew\" size=6><nobr>$spec</nobr></font></td>\n";
   }
    //need to change
   $MSG=$MSG."<td><a href=\"s.php?N=1&k=$ARAW[6]\">$ARAW[6]</a></td>"; //SN
    /*******
   $ARAW[7]=hebpar($ARAW[7],$graph);//>
   $MSG=$MSG."<td>$ARAW[7]</td>";
    *****/
   $ARAW[8]=hebpar($ARAW[8],$graph);
   $MSG=$MSG."<td>$ARAW[8]</td>";//A
   if ($graph)
   {
      $spec=pfont(mscode($ARAW[9]));//쫬
      $MSG=$MSG."<td align=\"right\">$spec</td>";
   }
   else
   {
      $spec=htmlspecialchars(mscode($ARAW[9]));//쫬
      $MSG=$MSG."<td align=\"right\"><font face=\"COBSHebrew\" size=6><nobr>$spec</nobr></font></td>";
   }
   $ARAW[10]=hebpar($ARAW[10],$graph);
   $MSG=$MSG."<td>$ARAW[10]</td>";//²nNq
   $ARAW[11]=hebpar($ARAW[11],$graph);
   $MSG=$MSG."<td>$ARAW[11]</td></tr>";//Ƶ
}
$MSG=$MSG."</table>";
   $QUERY="select engs, chap, sec from lparsing  where id=$oldid + 1";
    $result1=db_exec($db_conn,$QUERY);
 if (!$result1){
                        echogb("Ʈwupdate~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result1);
 if ($numrow>0)
 {
        $ARA=db_fetch_row($result1,0); //Ū@O
        $ARA[0]=trim($ARA[0]);
        $NEXT=urlencode($ARA[0]);
	if ($sec>0)
        	$MSG=$MSG."<br>\n<a href=\"$PHP_SELF?graph={$graph}&engs={$NEXT}&chap={$ARA[1]}&sec={$ARA[2]}\">U@`</a>";
 	else
        	$MSG=$MSG."<br>\n<a href=\"$PHP_SELF?graph={$graph}&engs={$NEXT}&chap={$ARA[1]}\">U@</a>";
 }

/*******ݭnsX@U? urlencode($userinput) ******/
$OUTMAIN=join( "", file( "parsing.cfg" ) );
$OUTMAIN=str_replace("%engs%",$engs,$OUTMAIN);
$OUTMAIN=str_replace("%chineses%",$ARAW[14],$OUTMAIN);
$OUTMAIN=str_replace("%chinesef%",$ARAW[15],$OUTMAIN);
$OUTMAIN=str_replace("%chap%",(int) $chap,$OUTMAIN);
$OUTMAIN=str_replace("%sec%",$oldsec,$OUTMAIN);
$OUTMAIN=str_replace("%book%",$book,$OUTMAIN);
$OUTMAIN=str_replace("%origtxt%",$origtxt,$OUTMAIN);
$big=str_replace("\n","\n\n",$big);
$OUTMAIN=str_replace("%big%",$big,$OUTMAIN);
$OUTMAIN=str_replace("%data%",$MSG,$OUTMAIN);
/****** Nparsing %data% ******/
echogb($OUTMAIN);
echo "</center>";
echogb("pGo{~Ap<a href=\"mailto:bible@fhl.net\">CBOLpe</a>C\n");
echogb("ƥѱfkhѡA޳N<a href=\"http://www.fhl.net\">HRT</a>");
echogb("<a href=\"http://bible.fhl.net\">CBOLpe</a>ѡAgϥΦCǧۥC<br>");
echogb("CBOLpeƪvŧiĥ<a href=\"http://bible.fhl.net/new/fdl.txt\">GNU Free Documentation License</a>AUBS4/NA27PBHS");
echogb("tgvҦ̶ȱvHRT ߡC");
?>
